@@ -2,8 +2,8 @@
 
 ;; Author: p-snow <public@p-snow.org>
 ;; Maintainer: p-snow <public@p-snow.org>
-;; Package-Version: 20250610.1142
-;; Package-Revision: c32eebcd1794
+;; Package-Version: 20260215.734
+;; Package-Revision: 2c4215499c08
 ;; Package-Requires: ((emacs "29.1") (request "0.3.0") (enlive "0.0.1") (gnuplot "0.8.1"))
 ;; Homepage: https://github.com/p-snow/org-web-track
 ;; Keywords: org, agenda, web, hypermedia
@@ -137,7 +137,7 @@ If SELECTOR is a string, it is assumed to be a shell command that should accept
 the HTTP response content as stdin and return a value as stdout."
   :type '(alist :key-type (string :tag "Regexp")
                 :value-type
-                (choice (vector :tag "A CSS selector")
+                (choice (vector :tag "A CSS selector" symbol)
                         (string :tag "A shell command that processes HTTP response content")
                         function))
   :group 'org-web-track)
@@ -240,6 +240,19 @@ used."
   :group 'org-web-track)
 
 
+(defmacro org-web-track-in-agenda-view (&rest body)
+  "Execute BODY and show its results in agenda view customized for `org-web-track'."
+  (declare (indent defun))
+  `(let ((org-columns-modify-value-for-display-function
+          'org-web-track-display-values)
+         (org-columns-default-format-for-agenda (org-web-track-columns-format))
+         (org-agenda-files (org-web-track-files))
+         (org-agenda-sorting-strategy '((tags user-defined-up)))
+         (org-agenda-cmp-user-defined 'org-web-track-cmp-updated-time)
+         (org-agenda-view-columns-initially t))
+     ,@body))
+
+
 (defun org-web-track-files ()
   "Return a list of files that contain tracking entries."
   (pcase org-web-track-files
@@ -377,14 +390,31 @@ the configuration in the variable `org-log-into-drawer'."
 
 ;;;###autoload
 (defun org-web-track-update-files ()
-  "Update all track items in variable `org-web-track-files'.
+  "Update all items in variable `org-web-track-files'.
 
-Return a list of markers pointing to items where the value has been updated."
+If called interactively and there are some updated items, this function
+shows them in an agenda view. If called from an Elisp function, the
+function returns a list of markers pointing to items whose values have
+been updated."
   (interactive)
-  (delq nil (org-map-entries (lambda ()
-                               (org-web-track-update-entry (point-marker)))
-                             (format "%s={.+}" org-web-track-url)
-                             (org-web-track-files))))
+  (when-let ((updated-item-markers
+              (delq nil (org-map-entries (lambda ()
+                                           (org-web-track-update-entry (point-marker)))
+                                         (format "%s={.+}" org-web-track-url)
+                                         (org-web-track-files)))))
+    (if (called-interactively-p 'any)
+        (org-web-track-in-agenda-view
+          (org-search-view nil
+                           (format "*{%s}"
+                                   (mapconcat (lambda (chg)
+                                                (org-with-point-at chg
+                                                  (shell-quote-argument
+                                                   (substring-no-properties
+                                                    (org-get-heading t t t t)))))
+                                              updated-item-markers
+                                              "\\|"))
+                           nil))
+      updated-item-markers)))
 
 (defun org-web-track-retrieve-values (url selectors &optional http-headers unix-socket)
   "Retrieve values using URL, SELECTORS, HTTP-HEADERS and UNIX-SOCKET.
@@ -661,13 +691,7 @@ This command invokes `org-agenda-columns' with `org-web-track-columns-format'
 to display current changes on tracking items in variable `org-web-track-files'
 along with the updated time."
   (interactive)
-  (let ((org-columns-modify-value-for-display-function
-         'org-web-track-display-values)
-        (org-columns-default-format-for-agenda (org-web-track-columns-format))
-        (org-agenda-files (org-web-track-files))
-        (org-agenda-sorting-strategy '((tags user-defined-up)))
-        (org-agenda-cmp-user-defined 'org-web-track-cmp-updated-time)
-        (org-agenda-view-columns-initially t))
+  (org-web-track-in-agenda-view
     (org-tags-view nil (format "%s={.+}" org-web-track-url))))
 
 (defun org-web-track-cmp-updated-time (a b)
